#
# spec file for package swipl
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           swipl
Version:        9.3.20
Release:        1.3
Summary:        Prolog Compiler
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
URL:            https://www.swi-prolog.org
Source0:        https://www.swi-prolog.org/download/devel/src/swipl-%{version}.tar.gz
Source98:       swipl-rpmlintrc
# For SOURCE_DATE_EPOCH variable- reproducible builds
Source99:       %{name}.changes
BuildRequires:  cmake
BuildRequires:  db-devel
BuildRequires:  fdupes
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  gperftools-devel
BuildRequires:  java-devel >= 1.8.0
BuildRequires:  python3-devel >= 3.6
# For %%check
BuildRequires:  junit
BuildRequires:  libarchive-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libunwind-devel
BuildRequires:  ncurses-devel
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  unixODBC-devel
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libedit)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(ossp-uuid)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw6)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(yaml-0.1)
BuildRequires:  hamcrest
Provides:       swi-prolog = %{version}
Provides:       swi_pl = %{version}
Obsoletes:      swi-prolog < %{version}
Obsoletes:      swi_pl < %{version}
# Builds on i586 don't seem to work (gh#SWI-Prolog/swipl-devel#1139)
ExcludeArch:    %ix86

#  jpackage-utils

%description
Edinburgh-style Prolog compiler including modules, autoload, libraries,
Garbage collector, stack expandor, C interface, GNU readline and GNU
Emacs interface, a very fast compiler,and an X11 interface using XPCE.

%prep
%autosetup -p1

sed -i -e "s|#!%{_bindir}/env swipl|#!%{_bindir}/swipl|" \
    packages/protobufs/bootstrap/protoc-gen-swipl

%build
export SOURCE_DATE_EPOCH="$(sed -n '/^----/n;s/ - .*$//;p;q' %{SOURCE99} | date -u -f - +%%s)"
%define __builder ninja
%cmake
%cmake_build

%install
%cmake_install

# # Fix script
# chmod +x %%{buildroot}%%{_libdir}/swipl-%%{version}/library/dialect/sicstus/swipl-lfr.pl
# sed -i "s@%%{_bindir}/../swipl.sh@%%{_bindir}/swipl@" %%{buildroot}%%{_docdir}/%%{name}-%%{version}/packages/examples/pldoc/man_server.pl

# Create common symlink for "pl"
ln -s swipl %{buildroot}%{_bindir}/pl

# Move *.pc file to correct location
install -D -m 0644 %{buildroot}%{_datadir}/pkgconfig/swipl.pc \
    %{buildroot}%{_libdir}/pkgconfig/swipl.pc
rm -v %{buildroot}%{_datadir}/pkgconfig/swipl.pc
rmdir -v %{buildroot}%{_datadir}/pkgconfig

%fdupes %{buildroot}/%{_libdir}/%{name}*
%fdupes %{buildroot}/%{_prefix}/lib/%{name}*
%fdupes %{buildroot}/%{_docdir}/%{name}-%{version}

%check
export LANG="C.utf8"
CTEST_OPT_ARGS=""
# gh#SWI-Prolog/swipl-devel#1139
%ifarch %ix86
CTEST_OPT_ARGS+=" --exclude-regex 'swipl:transaction'"
%endif
%ctest --verbose $CTEST_OPT_ARGS

%files
%license LICENSE README.md
%{_bindir}/pl
%{_bindir}/swipl
%{_bindir}/swipl-ld
# %%{_bindir}/swipl-rc
%{_prefix}/lib/swipl
%dir %{_prefix}/lib/cmake
%{_prefix}/lib/cmake/swipl
# %%{_bindir}/xpce-client
# %%{_libdir}/%%{name}-%%{version}
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man1/swipl-ld.1%{?ext_man}
# %%{_mandir}/man1/swipl-rc.1%%{?ext_man}
%{_mandir}/man1/swipl.1%{?ext_man}
# %%{_mandir}/man1/xpce-client.1%%{?ext_man}

%changelog
* Fri Feb 21 2025 Matej Cepl <mcepl@cepl.eu>
- Update to 9.3.20:
  Complete changelog is
  https://www.swi-prolog.org/ChangeLog?branch=development&from=9.3.19&to=9.3.20
  and upstream still doesn’t provide any abbreviated version, and
  the list of changes is still too long to enumerate here.
* Tue Feb  4 2025 Lucas Mulling <lucas.mulling@suse.com>
- Update to 9.3.19:
  Complete changelog is
  https://www.swi-prolog.org/ChangeLog?branch=development&from=9.3.18&to=9.3.19
  and upstream still doesn’t provide any abbreviated version, and
  the list of changes is still too long to enumerate here.
* Wed Jan  8 2025 Matej Cepl <mcepl@cepl.eu>
- Update to 9.3.18:
  Complete changelog is
  https://www.swi-prolog.org/ChangeLog?branch=development&from=9.3.15&to=9.3.18
  and upstream still doesn’t provide any abbreviated version, and
  the list of changes is still too long to enumerate here.
- Remove upstreamed patch:
  - 104-fix-prolog_in_java.patch
* Fri Nov 22 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 9.3.15:
  Complete changelog is
  https://www.swi-prolog.org/ChangeLog?branch=development&from=9.3.12&to=9.3.15
  and upstream still doesn’t provide any abbreviated version, and
  the list of changes is still too long to enumerate here.
- Add 104-fix-prolog_in_java.patch to fix failing test jpl:prolog_in_java
* Wed Oct  9 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 9.3.12
  Complete changelog is
  https://www.swi-prolog.org/ChangeLog?branch=development&from=9.3.11&to=9.3.12
  and upstream still doesn’t provide any abbreviated version, and
  the list of changes is still too long to enumerate here.
* Tue Sep 24 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 9.3.11
  Complete changelog is
  https://www.swi-prolog.org/ChangeLog?branch=development&from=9.3.10&to=9.3.11
  and upstream still doesn’t provide any abbreviated version, and
  the list of changes is still too long to enumerate here.
* Sat Sep  7 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 9.3.10:
  Complete changelog is
  https://www.swi-prolog.org/ChangeLog?branch=development&from=9.3.8&to=9.3.10
  and upstream still doesn’t provide any abbreviated version.
* Mon Jul 22 2024 Matej Cepl <mcepl@cepl.eu>
- Add missing dependency … python3-devel.
* Thu Jul 18 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 9.3.8:
  Complete changelog is
  https://www.swi-prolog.org/ChangeLog?branch=development&from=9.3.7&to=9.3.8
  and upstream still doesn’t provide any abbreviated version.
* Thu Jun  6 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 9.3.7:
  Complete changelog is
  https://www.swi-prolog.org/ChangeLog?branch=development&from=9.3.2&to=9.3.7
  and upstream still doesn’t provide any abbreviated version.
- Skipping build on 32bit platforms (gh#SWI-Prolog/swipl-devel#1139)
* Mon Mar  4 2024 Matej Cepl <mcepl@cepl.eu>
- Update to the devel version 9.3.2. Unfortunately, the number
  of changes is so large and the upstream doesn't keep a
  changelog file, so I have to refer you to the web page
  https://www.swi-prolog.org/.
* Tue Jul  4 2023 Matej Cepl <mcepl@suse.com>
- Make rpmlint slightly less unhappy with us.
* Tue Mar  7 2023 Matej Cepl <mcepl@suse.com>
- Update to 9.0.4:
  - again a way too detailed changelog is available at
    https://www.swi-prolog.org/ChangeLog?branch=stable&from=8.4.3&to=9.0.4
- Skip failing test swipl:transaction (gh#SWI-Prolog/swipl-devel#1139)
* Sun Sep 11 2022 Matej Cepl <mcepl@suse.com>
- Update to 8.4.3:
  Changelog is not easily available. The best I was able to find is
  https://swi-prolog.discourse.group/t/ann-swi-prolog-8-4-3-stable/5541
- Removed obsolete patches:
  - pkgconfig.patch
  - swipl-ppc64.patch
* Sun Sep 11 2022 Matej Cepl <mcepl@suse.com>
- Cleanup the SPEC file.
* Wed Mar 28 2018 guillaume@opensuse.org
- Update to 7.6.4 (fixes aarch64 build)
- Remove upstreamed patches:
  * fix-implicit-fortify-decl.patch
  * reproducible-builds.patch
* Tue Mar 14 2017 rpm@fthiessen.de
- Update to version 7.4.1
- Removed PREPARE_PACKAGE as we can now use SourceURLs,
  which is prefered.
- Removed now useless pl.patch
- Removed invalid internal_fix.patch (leads to failing tests)
- Added reproducible-builds.patch to allow build with fake time
  use the SOURCE_DATE_EPOCH variable.
- Added fix-implicit-fortify-decl.patch to fix build with
  new glibc on Factory, fixes boo#1023722.
* Thu Sep 10 2015 antoine.belvire@laposte.net
- Add PREPARE_PACKAGE to sources.
* Wed Sep  9 2015 antoine.belvire@laposte.net
- Update to version 7.2.2.
- SWI-Prolog 7 at a glance:
  * The new dict type and syntax provides both time and space
    efficient name-value maps with a pleasant syntax.
  * As a consequence, it was necessary to replace the list
    constructor .(H,T) by the (also in use by Mercury) '[|]'(H,T).
  * The syntax "..." is now mapped to strings. Strings are
    compatible with ECLiPSe.
  * Thanks to Torbjorn Lager, we have "Pengines", Prolog engines on
    the web. This provides a generic API to talk comfortably to a
    Prolog server from JavaScript and other Prolog instances.
  * Markus Triska added clp(b), the boolean constraint solver,
    improved his clp(fd) and was before several enhancements to the
    toplevel dealing with constraints.
  * Thanks to Matt Lilley and Mike Elston, there is CQL, a DSL
    (Domain Specific Language) for dealing with SQL.
  * Matt Lilley improved networking support significantly,
    including much better support for SSL and general support for
    both HTTP and SOCKS proxy servers.
  * Many people have provided add-ons (packs) that rely on
    SWI-Prolog version 7. See http://www.swi-prolog.org/pack/list.
* Wed Jul 23 2014 dvaleev@suse.com
- update swipl-ppc64.patch to fix powerpc builds
  ppc64le now have ppc64 as java_libarch
* Tue Jul 22 2014 mihailjp@gmail.com
- Update to version 6.6.6
* Mon Dec 23 2013 dvaleev@suse.com
- extend swipl-ppc64 patch to cover ppc64le as well
- modified patches:
  * swipl-ppc64.patch
* Fri Mar  1 2013 coolo@suse.com
- update license to new format
* Fri Oct  5 2012 dvaleev@suse.com
- fix jpl build on powerpc64 (swipl-ppc64.patch)
* Tue Jun 26 2012 mvyskocil@suse.cz
- build require java-devel >= 1.6.0
* Sun May  6 2012 poletti.marco@gmail.com
- Make pkg-config detect the right include directory (bug 758354).
* Sat Dec 18 2010 coolo@novell.com
- update to 5.10.2 to fix build with latest Xorg
  * bug fixes, no detailed changelog for patch level releases
* Wed May 19 2010 poletti.marco@gmail.com
- Removed all the bench/ directory, because those files are not
  used and some of them have copyright issues.
* Mon May 17 2010 poletti.marco@gmail.com
- Removed unused file bench/simple_analyzer.pl for copyright issues.
- Cleaned up spec file, that is now using RPM_OPT_FLAGS.
* Thu Apr 22 2010 poletti.marco@gmail.com
- Update to 5.10.0
- Rewrote the spec file from scratch, removing old stuff.
* Fri Feb 19 2010 poletti.marco@gmail.com
- Update to 5.8.3
  * Many new features
  * Bug fixes
  * Removed the old < 2.5.x foreign language interface compatibility.
- Split package in swi-prolog, swi-prolog-doc and swi-prolog-devel
- Changed location of some files
* Mon Aug 11 2008 sndirsch@suse.de
- update to 5.6.59
  * fixes/enhancements
* Sun Jul 20 2008 sndirsch@suse.de
- update to 5.6.57
  * fixes/enhancements
* Sun Apr 20 2008 sndirsch@suse.de
- update to 5.6.54
  * fixes/enhancements
* Thu Apr  3 2008 schwab@suse.de
- Fix broken configure checks.
- Fix missing null check.
- Enable parallel build.
* Mon Mar 17 2008 sndirsch@suse.de
- update to 5.6.52
  * fixes/enhancements
* Sun Mar  9 2008 sndirsch@suse.de
- update to 5.6.51
  * fixes/enhancements
* Sun Feb 10 2008 sndirsch@suse.de
- update to 5.6.50
  * mainly bugfixes
* Tue Dec 18 2007 sndirsch@suse.de
- update toe 5.6.48
  * mainly bugfixes
* Wed Nov 21 2007 sndirsch@suse.de
- update to 5.6.47
  * mainly bugfixes
* Tue Aug  7 2007 sndirsch@suse.de
- update to 5.6.38
  * mainly bugfixes
* Thu May 24 2007 sndirsch@suse.de
- make rpmlint happy
* Sat May 12 2007 sndirsch@suse.de
- update to 5.6.34
  * various bugfixes
* Fri Apr 20 2007 sndirsch@suse.de
- switched to TeXLive packages
* Fri Oct 20 2006 sndirsch@suse.de
- update to 5.6.22
  * various bugfixes
* Mon Sep  4 2006 sndirsch@suse.de
- no longer try to install a PDF, which simply does not exist
* Sun Sep  3 2006 sndirsch@suse.de
- update to 5.6.18
  * various bugfixes
* Sun Jul  9 2006 sndirsch@suse.de
- disabled tests for now
* Mon Jun 12 2006 sndirsch@suse.de
- update to 5.6.13:
  * FIXED: Multi-threaded problem in dynamic predicate reindexing.
    Thanks to test program by Sergey Tikhonov.
  * FIXED: Atom-GC crash related to dynamic predicates.  Thanks to
    test program by Sergey Tikhonov.
  * FIXED: Bug#168: library(url), www_form_encode/2 to perform
    UTF-8 based Unicode encoding and decoding.  Library now based
    on current RFC3986.
  * ADDED: library(utf8): provide encoding and decoding of UTF-8
    strings.
  * FIXED: handling errors from the handler of call_cleanup/3.
    Bart Demoen and Marek Winkler.
  * FIXED: wrong error and possible crash if format/3 finds an
    illegal ~ sequence. Pierpaolo Bernardi.
* Sat Apr 15 2006 sndirsch@suse.de
- update to 5.6.12:
  * bugfix release
* Sat Apr  1 2006 schwab@suse.de
- Remove use of kernel headers to fix build on ppc.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 sndirsch@suse.de
- update to 5.6.3
  * obsoletes pl-5.6.2.tar.gz/pl-5.6.2.diff
* Thu Jan 19 2006 sndirsch@suse.de
- updated to stable release 5.6.2 (5.5.x were beta releases)
  * "5.6.2 is doing very nice on 2.6 kernels (fixes some loss of
    threading functionality after the 2.4 versions)"
- added gmp/gmp-devel to #neededforbuild (required since 5.5.39)
- pl-5.6.2.diff:
  * fixes from CVS as long as 5.6.3 is not released yet
  - FIXED: unify_with_occurs_check/2 fails to to occurs-check
    with attributed variables.
  - FIXED: Thread resource exception handling in Linux 2.6
  - packages/http:
  * Fixed redirect handling if the option to(Stream) is given
  - packages/semweb:
  * ADDED: exported rdf_quote_uri/2 implementing unicode
    quoting rules for URIs.
  - packages/xpce:
  * ENHANCED: PceEmacs colouring: more aggressive colouring
    of the current clause
  * ADDED: Bug#136: actually use directory argument in
    display<-win_directory.
* Sat Nov 19 2005 sndirsch@suse.de
- updated to release 5.5.37
* Sun Oct 30 2005 sndirsch@suse.de
- updated to release 5.5.36
* Sun Oct 16 2005 sndirsch@suse.de
- updated to release 5.5.34
* Sat Oct  1 2005 sndirsch@suse.de
- updated to release 5.5.33
* Sat Aug 27 2005 sndirsch@suse.de
- updated to bugfix release 5.5.27:
  * FIXED: handling @ in format/3.
  * FIXED: Indexing error in large negative integers. Introduced
    with 64-bit arithmetic.
  * FIXED: PL_unify_pointer()/PL_get_pointer().
  * FIXED: parsing hostnames in library(url).
  * XPCE changes:
  - FIXED: `menu->selection' for single-selection menus sometimes
    wasn't honoured.
  - FIXED: PceEmacs: colourising of use_module directives
    pointing to non-existing files.
  - FIXED: `file->kind'.   Petter Egesund.
* Sat Aug 13 2005 sndirsch@suse.de
- updated to bugfix release 5.5.26:
  Bugfixes:
  * loading of CHR library
  * CHR optimiser
  * handling RDF holding Unicode characters
* Tue Jul 26 2005 sndirsch@suse.de
- updated to release 5.5.23
* Wed Jul 13 2005 sndirsch@suse.de
- updated to release 5.5.21
* Mon Jul  4 2005 sndirsch@suse.de
- use RPM_OPT_FLAGS
* Sat Jul  2 2005 sndirsch@suse.de
- updated to release 5.5.20
  * obsoletes rfc2045.diff
* Mon Jun  6 2005 sndirsch@suse.de
- updated to release 5.5.19
- obsoletes pl-5.5.16.diff
- rfc2045.diff
  * added missing include path
* Sat May  7 2005 sndirsch@suse.de
- updated to release 5.5.16
- pl-5.5.16.diff:
  * fixes testsuite on 64bit-platforms (from CVS)
* Fri Apr 29 2005 sndirsch@suse.de
- updated to release 5.5.15
* Tue Apr 26 2005 uli@suse.de
- disabled make check for ARM (hangs QEMU)
* Fri Apr 22 2005 sndirsch@suse.de
- updated to current CVS version (05-04-22)
  * obsoletes pl-5.5.14.patch
* Thu Apr 21 2005 sndirsch@suse.de
- updated to current CVS version (05-04-21)
  * obsoletes linker-hack.diff
* Wed Apr 20 2005 sndirsch@suse.de
- updated reference manual and userguide
* Tue Apr 19 2005 sndirsch@suse.de
- fixed tarball filename
- linker-hack.diff:
  * hack to fix xpce build on ppc/ppc64/x86_64 (Bug #65102)
* Tue Apr 19 2005 sndirsch@suse.de
- updated to current CVS version, which fixes gcc4 issues; link
  problems still persist on ppc/ppc64/x86_64, therefore the build
  of xpce is still disabled on these archs (Bug #65102)
* Mon Apr 18 2005 sndirsch@suse.de
- updated to release 5.5.14
* Wed Apr 13 2005 sndirsch@suse.de
- disabled xpce package on %%ix86 as well to fix build :-(
* Thu Feb 10 2005 ro@suse.de
- remove dropped tetex subpackages from nfb
* Fri Jan 28 2005 sndirsch@suse.de
- updated to release 5.4.6
* Sun Jan 23 2005 sndirsch@suse.de
- disabled xpce package on ppc/ppc64/x86_64 to fix build on these
  platforms
* Thu Dec 23 2004 mcihar@suse.cz
- update to 5.4.5, most patches were merged upstream
* Sat Apr 24 2004 sndirsch@suse.de
- use xorg-x11 packages
* Tue Mar  2 2004 mcihar@suse.cz
- floatconv-2 test changed to work on all arches
* Wed Feb 25 2004 mcihar@suse.cz
- better fix for sizeofClause
- exclude one test on ppc64 as it currently can not pass because of
  precision of types there
* Tue Feb 24 2004 mcihar@suse.cz
- update to 5.2.13
- fix char vs. int comparsion
- fix pointer to int cast
* Mon Jan 12 2004 mcihar@suse.cz
- update to 5.2.11
- little spec file cleanup
- add freetype2 to neededforbuild as it is needed for Xvfb
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Aug 11 2003 mcihar@suse.cz
- run tests during build
- updated to 5.2.5
- remove quick load files
* Fri Jun  6 2003 mcihar@suse.cz
- don't include readline(3) man page
* Wed May 28 2003 mcihar@suse.cz
- updated to 5.2.0:
  * Multi-threading on MS-Windows and POSIX systems
  * Stable version of the ODBC database interface
  * Many updates to the SGML/XML packages
  * RDF support updated to latest W3C recommendations
  * Added HTTP server and client libraries
  * Added alarm and timeout handling as well as resource limits
  * Execution profiling now also for Windows platform
  * New information gathering and display for execution profiling
  * Better conformance to Windows keyboard accelerators
  * Many small improvements and bugfixes to all parts of the system
- included unpackaged man pages
* Thu May 15 2003 mcihar@suse.cz
- move more documentation to %%{_defaultdocdir}/swi-prolog
* Wed Dec  4 2002 mcihar@suse.cz
- man pages installed into /usr/share/man, where they should belong
- all doc is accesible from /usr/share/doc/packages/swi-prolog
- included demo
- using Xvfb for installation (it fails without X)
- updated to 5.0.10, among others, there were following changes:
  * FIXED: incorrect messages about not being able to import predicates
    from module user.
  * FIXED: GCC 3.2/SPARC problems and Solaris 9 portability issues.
    Thanks to Pieter Donche for providing access to their machine.
  * FIXED: Report variables _starting_ with an _ (e.g. _X) in the
    variable_names(Names) option of read_term.
  * ADDED: -nosignals option to inhibit signal handling.  Added a section
    to the manual about embedding in complicated environments. With help of
    David Sitsky.
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xshared> to <x-devel-packages>
- changed neededforbuild <xdevel> to <>
* Mon Aug 12 2002 vinil@suse.cz
- new version: 5.0.8
* Tue Feb 12 2002 nadvornik@suse.cz
- updated to 5.0.1
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Mon Jan 28 2002 vinil@suse.cz
- new version 4.1.0
  (it should be 4.0.11 down there...)
    | | |
    V V V
* Thu Dec 13 2001 vinil@suse.cz
- new version 2.4.11
* Sun Aug 26 2001 vinil@suse.cz
- update to 4.0.9
- get rid of patches (author accepted them)
- pdf and html manual included
- pdf and html manuals for packages included
* Tue May  1 2001 schwab@suse.de
- Add xshared to neededforbuild.
- Fix invalid casts.
- Use new readline API.
- Don't allow unaligned accesses on ia64.
- Force alignment to sizeof(double) on sparc.
* Sun Apr 29 2001 kukuk@suse.de
- Copy dev_t variable
- Compile only with "-g" on SPARC
- Remove wrong prototype for gethostname
* Thu Apr 19 2001 vinil@suse.cz
- upgrade to 4.0.3
- xpce GUI added to rpm (gpp, libgpp, xdevel added for abuild)
- buildroot removed because of _UGLY_ build system of the source
* Thu Feb 22 2001 ro@suse.de
- added readline/readline-devel to neededforbuild (split from bash)
* Fri Nov 24 2000 vinil@suse.cz
- upgraded to 3.4.2
- renamed from swi_pl to swi-prolog
* Mon Aug 21 2000 vinil@suse.cz
- upgraded to 3.3.9
- gz -> bz2
* Tue Jun 20 2000 schwab@suse.de
- Add support for ia64.
* Tue Jun 20 2000 kasal@suse.de
- upgraded to 3.3.8
* Mon Jun 19 2000 kasal@suse.de
- upgraded to 3.3.7
* Fri Mar 10 2000 kasal@suse.cz
- upgraded to 3.3.4
* Fri Mar  3 2000 kasal@suse.de
- changed %%{mandir} to %%{_mandir}
* Tue Feb 22 2000 kasal@suse.cz
- upgraded to 3.3.2
* Wed Feb 16 2000 kasal@suse.cz
- upgraded to 3.3.0
- got rid of Makefile.Linux
- added buildroot
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Nov 16 1998 ro@suse.de
- force host=i586-linux
* Sun Jun  8 1997 rj@suse.de
- new version 2.8.6
  - absolute links removed (hopefully)
* Thu Jan  2 1997 rj@suse.de
- new version 2.7.14
